diff src/term.c @ 27128:5cd86a04d3ef

(encode_terminal_code): Fix the previous change.
author Kenichi Handa <handa@m17n.org>
date Tue, 04 Jan 2000 01:55:22 +0000
parents 8de2d17323c2
children fd4d74bc1e42
line wrap: on
line diff
--- a/src/term.c	Tue Jan 04 01:53:54 2000 +0000
+++ b/src/term.c	Tue Jan 04 01:55:22 2000 +0000
@@ -966,8 +966,11 @@
 
 	      if (GLYPH_SIMPLE_P (tbase, tlen, g))
 		{
-		  /* We set the multi-byte form of C at WORKBUF.  */
-		  len = CHAR_STRING (src->u.ch, workbuf);
+		  /* We set the multi-byte form of a character in G
+		     (that should be an ASCII character) at
+		     WORKBUF.  */
+		  workbuf[0] = FAST_GLYPH_CHAR (g);
+		  len = 1;
 		  buf = workbuf;
 		}
 	      else